"""
TODO: We sometimes encourage you to keep trying things on a given exercise
even after you already figured it out. If you got everything working and feel
ready for the next exercise press enter `n` in the terminal.

The exercise file will be reloaded when you change one of the lines below!
Try adding a new `print` statement and check the updated output in the terminal.

"""


def main():
    print(r"       Welcome to...                ")
    print(r"               _ _                  ")
    print(r"  _ __  _   _ | (_)_ __   __ _ ___  ")
    print(r" | '_ \| | | || | | '_ \ / _` / __| ")
    print(r" | |_) | |_| || | | | | | (_| \__ \ ")
    print(r" | .__/ \__, ||_|_|_| |_|\__, |___/ ")
    print(r" |_|    |___/            |___/      ")
    print()
    print("This exercise runs successfully. The remaining exercises contain a syntax")
    print(
        "or logic error. The central concept behind Pylings is to fix these errors and"
    )
    print("solve the exercises. Good luck!")
    print()
    print("The file of this exercise is `exercises/00_intro/intro1.py`. Have a look!")
    print("The current exercise path will always be shown under the progress bar.")
    print("You can click on the path to open the exercise file in your editor.")


if __name__ == "__main__":
    main()